@@ -1,8 +1,60 @@
 # -*- encoding: utf-8 -*-
-
 """
 A simple dependency injection library.
 
+Usage
+=====
+
+First decorate a class with ``@provides('a lookup name')``.
+
+>>> import syringe
+>>>
+>>> @syringe.provides('cure')
+... class Syrup:
+...     def drink(self, person):
+...         print('Nom nom')
+...         person.health = 100
+...
+
+Instantiate it. Note that it is not possible to instanciate another instance of
+a class decorated with the name ``cure``.
+
+>>> syrup = Syrup()
+
+Next inject it in another class using ``inject('a lookup name')``.
+
+>>> class Person:
+...     cure = syringe.inject('cure')
+...
+...     def drink_medicine(self):
+...         self.cure.drink(self)
+...
+
+When an instance of the ``Person`` class is created, the value of the injecte name
+is the instance of the provided and instantiated class.
+
+>>> person = Person()
+>>> person.health = 20
+>>> assert person.cure == syrup
+>>> person.drink_medicine()
+Nom nom
+>>> assert person.health == 100
+
+
+Mocking
+-------
+
+A mock instance can be inserted using ``syringe.mock('a lookup name')``
+
+>>> try:
+...     from unittest import mock
+... except:
+...     import mock
+...
+>>> m = syringe.mock('cure')
+>>> person.drink_medicine()
+>>> m.drink.assert_called_once_with(person)
+
 """
 import functools
 
@@ -20,7 +72,6 @@ __all__ = [
     'DuplicateProviderError',
     'get',
     'inject',
-    'Injector',
     'mock',
     'provides',
     'NoCandidateError'
@@ -81,7 +132,7 @@ def get(name):
     Returns the provided instance.
 
     Args:
-        name: The lookup name.
+        name (str): The lookup name.
 
     Returns:
         The provided instance.
@@ -92,46 +143,47 @@ def get(name):
     return _PROVIDERS[name]
 
 
-
-class Injector(object):
+class inject(object):
     """
-    Not to be used directly. Call :func:`inject` instead.
-
     Injects the instance of a provided class to the current context.
 
     """
     def __init__(self, name):
+        """
+        Args:
+            name (str): The lookup name.
+
+        """
         self.name = name
 
     def __get__(self, obj, value):
+        """
+        Returns:
+            The provided instance.
+
+        """
         if obj is None:
             return self
         return get(self.name)
 
 
-def inject(name):
-    """
-    Returns:
-        an :cls:`Injector` with the specified name.
-
-    """
-    return Injector(name)
-
-
-def mock(name, cls=None):
+def mock(name, m=None):
     """
     Provide a mock overriding any namespace conflicts.
 
+    If a second argument is passed, it is provided using the specified
+    name. Otherwise a new :class:`unittest.mock.Mock` instance is
+    provided.
+
     Args:
-        name: The name of the mock to provide.
-        cls: The optional mock class to provice.
+        name (str): The name of the mock to provide.
+        m: The optional object to provide as a mock.
 
     """
-    if cls is None:
-        cls = type(str(name), (mock_module.Mock,), {})
-    instance = cls()
-    _PROVIDERS[name] = instance
-    return instance
+    if m is None:
+        m = mock_module.Mock()
+    _PROVIDERS[name] = m
+    return m
 
 
 def clear():
